==> haskell-data-default-0.7.1.1-41-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-default.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-default
version:              0.7.1.1
visibility:           public
id:                   data-default-0.7.1.1-6BHwbWEbMIC6PlzqbJSGwa
key:                  data-default-0.7.1.1-6BHwbWEbMIC6PlzqbJSGwa
license:              BSD-3-Clause
maintainer:           <l.mai@web.de>
author:               Lukas Mai
synopsis:             A class for types with a default value
category:             Data
abi:                  d7ad507a34889e1079015ea41b9452ce
exposed:              True
exposed-modules:      Data.Default
import-dirs:          /usr/lib/ghc-8.8.1/site-local/data-default-0.7.1.1
library-dirs:         /usr/lib/ghc-8.8.1/site-local/data-default-0.7.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/data-default-0.7.1.1
hs-libraries:         HSdata-default-0.7.1.1-6BHwbWEbMIC6PlzqbJSGwa
depends:
    base-4.13.0.0 data-default-class-0.1.2.0-3WblArvKItDIiwkDl9AciG
    data-default-instances-containers-0.0.1-HYvTeARnwy09LdbyougJoS
    data-default-instances-dlist-0.0.1-4roxjWZ6ctaLyJWpSxTUbk
    data-default-instances-old-locale-0.0.1-BSBT71snpgVEb2Ithyw9MK

haddock-interfaces:
    /usr/share/doc/haskell-data-default/html/data-default.haddock

haddock-html:         /usr/share/doc/haskell-data-default/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-default-0.7.1.1-43-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-default.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-default
version:              0.7.1.1
visibility:           public
id:                   data-default-0.7.1.1-kkFWAw6t22HQTKxCfb2xV
key:                  data-default-0.7.1.1-kkFWAw6t22HQTKxCfb2xV
license:              BSD-3-Clause
maintainer:           <l.mai@web.de>
author:               Lukas Mai
synopsis:             A class for types with a default value
category:             Data
abi:                  2685a3a395f3625c47aaf09d98c36c4d
exposed:              True
exposed-modules:      Data.Default
import-dirs:          /usr/lib/ghc-8.8.1/site-local/data-default-0.7.1.1
library-dirs:         /usr/lib/ghc-8.8.1/site-local/data-default-0.7.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/data-default-0.7.1.1
hs-libraries:         HSdata-default-0.7.1.1-kkFWAw6t22HQTKxCfb2xV
depends:
    base-4.13.0.0 data-default-class-0.1.2.0-3WblArvKItDIiwkDl9AciG
    data-default-instances-containers-0.0.1-HYvTeARnwy09LdbyougJoS
    data-default-instances-dlist-0.0.1-83JOJWNUIbBKkw2Xnbk1jJ
    data-default-instances-old-locale-0.0.1-BSBT71snpgVEb2Ithyw9MK

haddock-interfaces:
    /usr/share/doc/haskell-data-default/html/data-default.haddock

haddock-html:         /usr/share/doc/haskell-data-default/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
